package eu.mhsl.minecraft.pixelblocks;

import eu.mhsl.minecraft.pixelblocks.pixelblock.PixelBlock;
import eu.mhsl.minecraft.pixelblocks.utils.HeadUtil;
import net.kyori.adventure.text.Component;
import net.kyori.adventure.text.format.NamedTextColor;
import org.bukkit.Bukkit;
import org.bukkit.Material;
import org.bukkit.NamespacedKey;
import org.bukkit.inventory.ItemStack;
import org.bukkit.inventory.Recipe;
import org.bukkit.inventory.ShapedRecipe;
import org.bukkit.inventory.meta.ItemMeta;
import org.jetbrains.annotations.NotNull;

import java.util.List;
import java.util.Optional;
import java.util.UUID;

public class PixelBlockItem {
    public static UUID unusedBlockID = UUID.fromString("98fdf0ae-c3ab-4ef7-ae25-efd518d600de");
    public static final String itemTexture = "eyJ0ZXh0dXJlcyI6eyJTS0lOIjp7InVybCI6Imh0dHA6Ly90ZXh0dXJlcy5taW5lY3JhZnQubmV0L3RleHR1cmUvYzE5NGU5ZTc3NTdkMDZkNmY1ZTViZTg0NTQ4YTdjYjUyMTczZDY4Y2NmODAyZDIxMTI3NWQzMWNkYmEwYTA2ZSJ9fX0=";
    public static final NamespacedKey recipeKey = new NamespacedKey(PixelBlocksPlugin.plugin, "pixelblock");

    public static @NotNull ItemStack getBlockAsItem(@NotNull PixelBlock block) {
        String ownerName = Optional.ofNullable(Bukkit.getOfflinePlayer(block.ownerUUID).getName()).orElseGet(() -> block.ownerUUID.toString());

        ItemStack itemStack = HeadUtil.getCustomTextureHead(itemTexture);
        ItemMeta meta = itemStack.getItemMeta();
        meta.itemName(Component.text(block.blockUUID.toString()));
        meta.displayName(Component.text("Pixelblock von " + ownerName));
        meta.lore(List.of(
            Component.text(ownerName + " ist der Besitzer dieses Blocks."),
            Component.text("Klicke auf den gesetzten Block, um diesen zu bearbeiten!"),
            Component.text(block.blockUUID.toString()).color(NamedTextColor.DARK_GRAY)
        ));
        meta.setEnchantmentGlintOverride(true);
        itemStack.setItemMeta(meta);

        return itemStack;
    }

    public static @NotNull ItemStack getEmptyPixelBlock() {
        ItemStack item = HeadUtil.getCustomTextureHead(itemTexture);
        ItemMeta meta = item.getItemMeta();
        meta.displayName(Component.text("Leerer Pixelblock"));
        meta.lore(List.of(
            Component.text("Der erste Spieler, der den Block platziert wird zum Besitzer des Blocks."),
            Component.text("Klicke auf den gesetzten Block, um diesen zu bearbeiten!")
        ));
        meta.setEnchantmentGlintOverride(true);
        meta.itemName(Component.text(unusedBlockID.toString()));
        item.setItemMeta(meta);
        return item;
    }

    public static @NotNull Recipe getRecipe() {
        ShapedRecipe recipe = new ShapedRecipe(recipeKey, getEmptyPixelBlock());
        recipe.shape("AEA", "BCB", "DDD");
        recipe.setIngredient('A', Material.GLASS);
        recipe.setIngredient('B', Material.DIAMOND_BLOCK);
        recipe.setIngredient('C', Material.HEART_OF_THE_SEA);
        recipe.setIngredient('D', Material.GRASS_BLOCK);
        recipe.setIngredient('E', Material.GLOW_BERRIES);
        return recipe;
    }
}

